Package 'ReliaShiny'

Title: A 'Shiny' App for Reliability Analysis
Description: An interactive web application for reliability analysis using the 'shiny' <https://shiny.posit.co/> framework. The app provides an easy-to-use interface for performing reliability analysis using 'WeibullR' <https://cran.r-project.org/package=WeibullR> and 'ReliaGrowR' <https://cran.r-project.org/package=ReliaGrowR>.
Authors: Paul Govan [aut, cre, cph] (ORCID: <https://orcid.org/0000-0002-1821-8492>)
Maintainer: Paul Govan <[email protected]>
License: CC BY 4.0
Version: 0.5
Built: 2026-06-03 22:02:48 UTC
Source: https://github.com/paulgovan/reliashiny

Help Index


Extract ALT summary as a data frame

Description

Extract ALT summary as a data frame

Usage

extract_alt_summ(alt_obj, digits = 4)

Arguments

alt_obj

Object returned by WeibullR.ALT::alt.fit().

digits

Number of decimal places to round numeric values.

Value

A two-column data frame with Param and Value.


Extract NHPP summary as a data frame

Description

Extract NHPP summary as a data frame

Usage

extract_nhpp_summ(nhpp_obj, digits = 4)

Arguments

nhpp_obj

Object returned by ReliaGrowR::nhpp().

digits

Number of decimal places to round numeric values.

Value

A two-column data frame with Param and Value.


Extract RGA summary as a data frame

Description

Extract RGA summary as a data frame

Usage

extract_rga_summ(rga_obj, digits = 4)

Arguments

rga_obj

Object returned by ReliaGrowR::rga().

digits

Number of decimal places to round numeric values.

Value

A two-column data frame with Param and Value.


Extract WeibullR summary as a data frame

Description

Extract WeibullR summary as a data frame

Usage

extract_wblr_summ(wblr_obj, digits = 4)

Arguments

wblr_obj

Object returned by WeibullR::wblr.fit().

digits

Number of decimal places to round numeric values.

Value

A two-column data frame with Param and Value.


A Shiny Reliability Analysis App.

Description

This function launches a Shiny application for reliability analysis.

Usage

ReliaShiny()

Value

This function does not return a value.

See Also

https://paulgovan.github.io/ReliaShiny/

Examples

if (interactive()) {
  ReliaShiny()
}