Welcome to ClientVPS Mirrors

Help for package ReliaShiny
Type: Package
Title: A 'Shiny' App for Reliability Analysis
Version: 0.4.1
Description: An interactive web application for reliability analysis using the 'shiny' https://shiny.posit.co/ framework. The app provides an easy-to-use interface for performing reliability analysis using 'WeibullR' https://cran.r-project.org/package=WeibullR and 'ReliaGrowR' https://cran.r-project.org/package=ReliaGrowR.
License: CC BY 4.0
Imports: magrittr, ReliaGrowR, ReliaPlotR, WeibullR, shiny, shinydashboard, shinyWidgets
Encoding: UTF-8
RoxygenNote: 7.3.3
URL: https://paulgovan.github.io/ReliaShiny/, https://github.com/paulgovan/ReliaShiny
BugReports: https://github.com/paulgovan/ReliaShiny/issues
Suggests: knitr, rmarkdown, shinytest2, testthat (≥ 3.0.0)
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2025-12-19 01:47:10 UTC; paulgovan
Author: Paul Govan ORCID iD [aut, cre, cph]
Maintainer: Paul Govan <paul.govan2@gmail.com>
Repository: CRAN
Date/Publication: 2025-12-19 10:20:35 UTC

Pipe operator

Description

See magrittr::%>% for details.

Usage

lhs %>% rhs

Arguments

lhs

A value or the magrittr placeholder.

rhs

A function call using the magrittr semantics.

Value

The result of calling 'rhs(lhs)'.


A Shiny Reliability Analysis App.

Description

This function launches a Shiny application for reliability analysis.

Usage

ReliaShiny()

Value

This function does not return a value.

See Also

https://paulgovan.github.io/ReliaShiny/

Examples

if (interactive()) {
  ReliaShiny()
}

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.