The hardware and bandwidth for this mirror is donated by METANET, the Webhosting and Full Service-Cloud Provider.
If you wish to report a bug, or if you are interested in having us mirror your free-software or open-source project, please feel free to contact us at mirror[@]metanet.ch.

Type: Package
Title: A 'Shiny' App for Reliability Analysis
Version: 0.5
Description: An interactive web application for reliability analysis using the 'shiny' https://shiny.posit.co/ framework. The app provides an easy-to-use interface for performing reliability analysis using 'WeibullR' https://cran.r-project.org/package=WeibullR and 'ReliaGrowR' https://cran.r-project.org/package=ReliaGrowR.
License: CC BY 4.0
Imports: magrittr, ReliaGrowR, ReliaPlotR, shinycssloaders, WeibullR, WeibullR.ALT, shiny, shinydashboard, shinyWidgets
Encoding: UTF-8
RoxygenNote: 7.3.3
URL: https://paulgovan.github.io/ReliaShiny/, https://github.com/paulgovan/ReliaShiny
BugReports: https://github.com/paulgovan/ReliaShiny/issues
Suggests: knitr, rmarkdown, shinytest2, testthat (≥ 3.0.0)
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2026-04-22 17:46:00 UTC; paulgovan
Author: Paul Govan ORCID iD [aut, cre, cph]
Maintainer: Paul Govan <paul.govan2@gmail.com>
Repository: CRAN
Date/Publication: 2026-04-22 18:20:02 UTC

Pipe operator

Description

See magrittr::%>% for details.

Usage

lhs %>% rhs

Arguments

lhs

A value or the magrittr placeholder.

rhs

A function call using the magrittr semantics.

Value

The result of calling 'rhs(lhs)'.


A Shiny Reliability Analysis App.

Description

This function launches a Shiny application for reliability analysis.

Usage

ReliaShiny()

Value

This function does not return a value.

See Also

https://paulgovan.github.io/ReliaShiny/

Examples

if (interactive()) {
  ReliaShiny()
}

Extract ALT summary as a data frame

Description

Extract ALT summary as a data frame

Usage

extract_alt_summ(alt_obj, digits = 4)

Arguments

alt_obj

Object returned by WeibullR.ALT::alt.fit().

digits

Number of decimal places to round numeric values.

Value

A two-column data frame with Param and Value.


Extract NHPP summary as a data frame

Description

Extract NHPP summary as a data frame

Usage

extract_nhpp_summ(nhpp_obj, digits = 4)

Arguments

nhpp_obj

Object returned by ReliaGrowR::nhpp().

digits

Number of decimal places to round numeric values.

Value

A two-column data frame with Param and Value.


Extract RGA summary as a data frame

Description

Extract RGA summary as a data frame

Usage

extract_rga_summ(rga_obj, digits = 4)

Arguments

rga_obj

Object returned by ReliaGrowR::rga().

digits

Number of decimal places to round numeric values.

Value

A two-column data frame with Param and Value.


Extract WeibullR summary as a data frame

Description

Extract WeibullR summary as a data frame

Usage

extract_wblr_summ(wblr_obj, digits = 4)

Arguments

wblr_obj

Object returned by WeibullR::wblr.fit().

digits

Number of decimal places to round numeric values.

Value

A two-column data frame with Param and Value.

These binaries (installable software) and packages are in development.
They may not be fully stable and should be used with caution. We make no claims about them.