| Title: | A 'Shiny' App for Reliability Analysis |
|---|---|
| Description: | An interactive web application for reliability analysis using the 'shiny' <https://shiny.posit.co/> framework. The app provides an easy-to-use interface for performing reliability analysis using 'WeibullR' <https://cran.r-project.org/package=WeibullR> and 'ReliaGrowR' <https://cran.r-project.org/package=ReliaGrowR>. |
| Authors: | Paul Govan [aut, cre, cph] (ORCID: <https://orcid.org/0000-0002-1821-8492>) |
| Maintainer: | Paul Govan <[email protected]> |
| License: | CC BY 4.0 |
| Version: | 0.5 |
| Built: | 2026-06-03 22:02:48 UTC |
| Source: | https://github.com/paulgovan/reliashiny |
Extract ALT summary as a data frame
extract_alt_summ(alt_obj, digits = 4)extract_alt_summ(alt_obj, digits = 4)
alt_obj |
Object returned by |
digits |
Number of decimal places to round numeric values. |
A two-column data frame with Param and Value.
Extract NHPP summary as a data frame
extract_nhpp_summ(nhpp_obj, digits = 4)extract_nhpp_summ(nhpp_obj, digits = 4)
nhpp_obj |
Object returned by |
digits |
Number of decimal places to round numeric values. |
A two-column data frame with Param and Value.
Extract RGA summary as a data frame
extract_rga_summ(rga_obj, digits = 4)extract_rga_summ(rga_obj, digits = 4)
rga_obj |
Object returned by |
digits |
Number of decimal places to round numeric values. |
A two-column data frame with Param and Value.
Extract WeibullR summary as a data frame
extract_wblr_summ(wblr_obj, digits = 4)extract_wblr_summ(wblr_obj, digits = 4)
wblr_obj |
Object returned by |
digits |
Number of decimal places to round numeric values. |
A two-column data frame with Param and Value.
This function launches a Shiny application for reliability analysis.
ReliaShiny()ReliaShiny()
This function does not return a value.
https://paulgovan.github.io/ReliaShiny/
if (interactive()) { ReliaShiny() }if (interactive()) { ReliaShiny() }